Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(453)

Unified Diff: third_party/WebKit/Source/core/layout/svg/LayoutSVGShape.cpp

Issue 2465983002: Rename "paint invalidation rect" etc. to "visual rect". (Closed)
Patch Set: - Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/svg/LayoutSVGShape.cpp
diff --git a/third_party/WebKit/Source/core/layout/svg/LayoutSVGShape.cpp b/third_party/WebKit/Source/core/layout/svg/LayoutSVGShape.cpp
index 266baa1a00c48b4f8aab03fb8e9124c762c500c4..95957e74b8a3280d25be8443b9498b33fd4cab83 100644
--- a/third_party/WebKit/Source/core/layout/svg/LayoutSVGShape.cpp
+++ b/third_party/WebKit/Source/core/layout/svg/LayoutSVGShape.cpp
@@ -181,15 +181,14 @@ void LayoutSVGShape::layout() {
bool updateParentBoundaries = false;
// updateShapeFromElement() also updates the object & stroke bounds - which
// feeds into the paint invalidation rect - so we need to call it for both
// the shape-update and the bounds-update flag, since .
if (m_needsShapeUpdate || m_needsBoundariesUpdate) {
updateShapeFromElement();
m_needsShapeUpdate = false;
- m_paintInvalidationBoundingBox = strokeBoundingBox();
- SVGLayoutSupport::intersectPaintInvalidationRectWithResources(
- this, m_paintInvalidationBoundingBox);
+ m_localVisualRect = strokeBoundingBox();
+ SVGLayoutSupport::adjustVisualRectWithResources(this, m_localVisualRect);
m_needsBoundariesUpdate = false;
updateParentBoundaries = true;
@@ -245,7 +244,7 @@ void LayoutSVGShape::paint(const PaintInfo& paintInfo,
void LayoutSVGShape::addOutlineRects(Vector<LayoutRect>& rects,
const LayoutPoint&,
IncludeBlockVisualOverflowOrNot) const {
- rects.append(LayoutRect(paintInvalidationRectInLocalSVGCoordinates()));
+ rects.append(LayoutRect(visualRectInLocalSVGCoordinates()));
}
bool LayoutSVGShape::nodeAtFloatPoint(HitTestResult& result,
@@ -181,15 +181,14 @@ void LayoutSVGShape::layout() {
bool updateParentBoundaries = false;
// updateShapeFromElement() also updates the object & stroke bounds - which
- // feeds into the paint invalidation rect - so we need to call it for both
- // the shape-update and the bounds-update flag, since .
+ // feeds into the visual rect - so we need to call it for both the
+ // shape-update and the bounds-update flag.
if (m_needsShapeUpdate || m_needsBoundariesUpdate) {
updateShapeFromElement();

Powered by Google App Engine
This is Rietveld 408576698